@@ -7,12 +7,7 @@ namespace Facile\OpenIDClient\Claims;
 use function array_filter;
 use Facile\OpenIDClient\Client\ClientInterface;
 use function is_array;
-use function is_string;
-use Throwable;
 
-/**
- * @psalm-import-type TokenSetClaimsType from \Facile\OpenIDClient\Token\TokenSetInterface
- */
 final class AggregateParser extends AbstractClaims implements AggregatedParserInterface
 {
     public function unpack(ClientInterface $client, array $claims): array
@@ -28,19 +23,12 @@ final class AggregateParser extends AbstractClaims implements AggregatedParserIn
             return $claims;
         }
 
-        /** @var array<string, array{JWT: string}> $aggregatedSources */
-        $aggregatedSources = array_filter($claimSources, static function ($value): bool {
-            return is_string($value['JWT'] ?? null);
-        });
+        $aggregatedSources = array_filter($claimSources, fn ($value): bool => $this->isAggregateSource($value));
 
         $claimPayloads = [];
         foreach ($aggregatedSources as $sourceName => $source) {
-            try {
-                $claimPayloads[$sourceName] = $this->claimJWT($client, $source['JWT']);
-                unset($claims['_claim_sources'][$sourceName]);
-            } catch (Throwable $e) {
-                throw $e;
-            }
+            $claimPayloads[$sourceName] = $this->claimJWT($client, $source['JWT']);
+            unset($claims['_claim_sources'][$sourceName]);
         }
 
         return $this->cleanClaims($this->assignClaims($claims, $claimNames, $claimPayloads));
