@@ -30,9 +30,7 @@ final class RemoteProvider implements RemoteProviderInterface
     {
         $lastException = null;
 
-        $providers = array_filter($this->providers, static function (RemoteProviderInterface $provider) use ($uri): bool {
-            return $provider->isAllowedUri($uri);
-        });
+        $providers = array_filter($this->providers, static fn (RemoteProviderInterface $provider): bool => $provider->isAllowedUri($uri));
 
         foreach ($providers as $provider) {
             try {
