@@ -25,28 +25,40 @@ use Amp\Success;
  */
 class AmpResolver implements Dns\Resolver
 {
-    private $dnsMap;
+    private array $dnsMap;
 
     public function __construct(array &$dnsMap)
     {
         $this->dnsMap = &$dnsMap;
     }
 
-    public function resolve(string $name, int $typeRestriction = null): Promise
+    public function resolve(string $name, ?int $typeRestriction = null): Promise
     {
-        if (!isset($this->dnsMap[$name]) || !\in_array($typeRestriction, [Record::A, null], true)) {
+        $recordType = Record::A;
+        $ip = $this->dnsMap[$name] ?? null;
+
+        if (null !== $ip && str_contains($ip, ':')) {
+            $recordType = Record::AAAA;
+        }
+        if (null === $ip || $recordType !== ($typeRestriction ?? $recordType)) {
             return Dns\resolver()->resolve($name, $typeRestriction);
         }
 
-        return new Success([new Record($this->dnsMap[$name], Record::A, null)]);
+        return new Success([new Record($ip, $recordType, null)]);
     }
 
     public function query(string $name, int $type): Promise
     {
-        if (!isset($this->dnsMap[$name]) || Record::A !== $type) {
+        $recordType = Record::A;
+        $ip = $this->dnsMap[$name] ?? null;
+
+        if (null !== $ip && str_contains($ip, ':')) {
+            $recordType = Record::AAAA;
+        }
+        if (null === $ip || $recordType !== $type) {
             return Dns\resolver()->query($name, $type);
         }
 
-        return new Success([new Record($this->dnsMap[$name], Record::A, null)]);
+        return new Success([new Record($ip, $recordType, null)]);
     }
 }
