@@ -2,21 +2,14 @@
 
 declare(strict_types=1);
 
-/*
- * The MIT License (MIT)
- *
- * Copyright (c) 2014-2021 Spomky-Labs
- *
- * This software may be modified and distributed under the terms
- * of the MIT license.  See the LICENSE file for details.
- */
-
 namespace Cose\Algorithm\Signature\ECDSA;
 
-use Assert\Assertion;
 use Cose\Algorithm\Signature\Signature;
 use Cose\Key\Ec2Key;
 use Cose\Key\Key;
+use InvalidArgumentException;
+use function openssl_sign;
+use function openssl_verify;
 
 abstract class ECDSA implements Signature
 {
@@ -34,7 +27,7 @@ abstract class ECDSA implements Signature
         $publicKey = $key->toPublic();
         $signature = ECSignature::toAsn1($signature, $this->getSignaturePartLength());
 
-        return 1 === openssl_verify($data, $signature, $publicKey->asPEM(), $this->getHashAlgorithm());
+        return openssl_verify($data, $signature, $publicKey->asPEM(), $this->getHashAlgorithm()) === 1;
     }
 
     abstract protected function getCurve(): int;
@@ -45,8 +38,10 @@ abstract class ECDSA implements Signature
 
     private function handleKey(Key $key): Ec2Key
     {
-        $key = new Ec2Key($key->getData());
-        Assertion::eq($key->curve(), $this->getCurve(), 'This key cannot be used with this algorithm');
+        $key = Ec2Key::create($key->getData());
+        if ($key->curve() !== $this->getCurve()) {
+            throw new InvalidArgumentException('This key cannot be used with this algorithm');
+        }
 
         return $key;
     }
