@@ -2,19 +2,11 @@
 
 declare(strict_types=1);
 
-/*
- * The MIT License (MIT)
- *
- * Copyright (c) 2014-2021 Spomky-Labs
- *
- * This software may be modified and distributed under the terms
- * of the MIT license.  See the LICENSE file for details.
- */
-
 namespace Cose\Algorithm\Signature\ECDSA;
 
 use function bin2hex;
 use function dechex;
+use function hex2bin;
 use function hexdec;
 use InvalidArgumentException;
 use function mb_strlen;
@@ -28,11 +20,17 @@ use const STR_PAD_LEFT;
 final class ECSignature
 {
     private const ASN1_SEQUENCE = '30';
+
     private const ASN1_INTEGER = '02';
+
     private const ASN1_MAX_SINGLE_BYTE = 128;
+
     private const ASN1_LENGTH_2BYTES = '81';
+
     private const ASN1_BIG_INTEGER_LIMIT = '7f';
+
     private const ASN1_NEGATIVE_INTEGER = '00';
+
     private const BYTE_SIZE = 2;
 
     public static function toAsn1(string $signature, int $length): string
@@ -52,17 +50,12 @@ final class ECSignature
         $totalLength = $lengthR + $lengthS + self::BYTE_SIZE + self::BYTE_SIZE;
         $lengthPrefix = $totalLength > self::ASN1_MAX_SINGLE_BYTE ? self::ASN1_LENGTH_2BYTES : '';
 
-        $bin = hex2bin(
+        return hex2bin(
             self::ASN1_SEQUENCE
-            .$lengthPrefix.dechex($totalLength)
-            .self::ASN1_INTEGER.dechex($lengthR).$pointR
-            .self::ASN1_INTEGER.dechex($lengthS).$pointS
+            . $lengthPrefix . dechex($totalLength)
+            . self::ASN1_INTEGER . dechex($lengthR) . $pointR
+            . self::ASN1_INTEGER . dechex($lengthS) . $pointS
         );
-        if (false === $bin) {
-            throw new InvalidArgumentException('Unable to convert into ASN.1');
-        }
-
-        return $bin;
     }
 
     public static function fromAsn1(string $signature, int $length): string
@@ -70,24 +63,19 @@ final class ECSignature
         $message = bin2hex($signature);
         $position = 0;
 
-        if (self::ASN1_SEQUENCE !== self::readAsn1Content($message, $position, self::BYTE_SIZE)) {
+        if (self::readAsn1Content($message, $position, self::BYTE_SIZE) !== self::ASN1_SEQUENCE) {
             throw new InvalidArgumentException('Invalid data. Should start with a sequence.');
         }
 
         // @phpstan-ignore-next-line
-        if (self::ASN1_LENGTH_2BYTES === self::readAsn1Content($message, $position, self::BYTE_SIZE)) {
+        if (self::readAsn1Content($message, $position, self::BYTE_SIZE) === self::ASN1_LENGTH_2BYTES) {
             $position += self::BYTE_SIZE;
         }
 
         $pointR = self::retrievePositiveInteger(self::readAsn1Integer($message, $position));
         $pointS = self::retrievePositiveInteger(self::readAsn1Integer($message, $position));
 
-        $bin = hex2bin(str_pad($pointR, $length, '0', STR_PAD_LEFT).str_pad($pointS, $length, '0', STR_PAD_LEFT));
-        if (false === $bin) {
-            throw new InvalidArgumentException('Unable to convert from ASN.1');
-        }
-
-        return $bin;
+        return hex2bin(str_pad($pointR, $length, '0', STR_PAD_LEFT) . str_pad($pointS, $length, '0', STR_PAD_LEFT));
     }
 
     private static function octetLength(string $data): int
@@ -98,11 +86,11 @@ final class ECSignature
     private static function preparePositiveInteger(string $data): string
     {
         if (mb_substr($data, 0, self::BYTE_SIZE, '8bit') > self::ASN1_BIG_INTEGER_LIMIT) {
-            return self::ASN1_NEGATIVE_INTEGER.$data;
+            return self::ASN1_NEGATIVE_INTEGER . $data;
         }
 
         while (
-            self::ASN1_NEGATIVE_INTEGER === mb_substr($data, 0, self::BYTE_SIZE, '8bit')
+            mb_strpos($data, self::ASN1_NEGATIVE_INTEGER, 0, '8bit') === 0
             && mb_substr($data, 2, self::BYTE_SIZE, '8bit') <= self::ASN1_BIG_INTEGER_LIMIT
         ) {
             $data = mb_substr($data, 2, null, '8bit');
@@ -121,7 +109,7 @@ final class ECSignature
 
     private static function readAsn1Integer(string $message, int &$position): string
     {
-        if (self::ASN1_INTEGER !== self::readAsn1Content($message, $position, self::BYTE_SIZE)) {
+        if (self::readAsn1Content($message, $position, self::BYTE_SIZE) !== self::ASN1_INTEGER) {
             throw new InvalidArgumentException('Invalid data. Should contain an integer.');
         }
 
@@ -133,7 +121,7 @@ final class ECSignature
     private static function retrievePositiveInteger(string $data): string
     {
         while (
-            self::ASN1_NEGATIVE_INTEGER === mb_substr($data, 0, self::BYTE_SIZE, '8bit')
+            mb_strpos($data, self::ASN1_NEGATIVE_INTEGER, 0, '8bit') === 0
             && mb_substr($data, 2, self::BYTE_SIZE, '8bit') > self::ASN1_BIG_INTEGER_LIMIT
         ) {
             $data = mb_substr($data, 2, null, '8bit');
