@@ -2,37 +2,34 @@
 
 declare(strict_types=1);
 
-/*
- * The MIT License (MIT)
- *
- * Copyright (c) 2014-2021 Spomky-Labs
- *
- * This software may be modified and distributed under the terms
- * of the MIT license.  See the LICENSE file for details.
- */
-
 namespace Webauthn;
 
 use function array_key_exists;
 use ArrayIterator;
 use Assert\Assertion;
 use function count;
+use const COUNT_NORMAL;
 use Countable;
 use Iterator;
 use IteratorAggregate;
+use const JSON_THROW_ON_ERROR;
 use JsonSerializable;
-use function Safe\json_decode;
 
+/**
+ * @implements IteratorAggregate<PublicKeyCredentialDescriptor>
+ */
 class PublicKeyCredentialDescriptorCollection implements JsonSerializable, Countable, IteratorAggregate
 {
     /**
      * @var PublicKeyCredentialDescriptor[]
      */
-    private $publicKeyCredentialDescriptors = [];
+    private array $publicKeyCredentialDescriptors = [];
 
-    public function add(PublicKeyCredentialDescriptor $publicKeyCredentialDescriptor): void
+    public function add(PublicKeyCredentialDescriptor ...$publicKeyCredentialDescriptors): void
     {
-        $this->publicKeyCredentialDescriptors[$publicKeyCredentialDescriptor->getId()] = $publicKeyCredentialDescriptor;
+        foreach ($publicKeyCredentialDescriptors as $publicKeyCredentialDescriptor) {
+            $this->publicKeyCredentialDescriptors[$publicKeyCredentialDescriptor->getId()] = $publicKeyCredentialDescriptor;
+        }
     }
 
     public function has(string $id): bool
@@ -42,7 +39,7 @@ class PublicKeyCredentialDescriptorCollection implements JsonSerializable, Count
 
     public function remove(string $id): void
     {
-        if (!$this->has($id)) {
+        if (! $this->has($id)) {
             return;
         }
 
@@ -63,18 +60,19 @@ class PublicKeyCredentialDescriptorCollection implements JsonSerializable, Count
     }
 
     /**
-     * @return array[]
+     * @return array<string, mixed>[]
      */
     public function jsonSerialize(): array
     {
-        return array_map(static function (PublicKeyCredentialDescriptor $object): array {
-            return $object->jsonSerialize();
-        }, $this->publicKeyCredentialDescriptors);
+        return array_map(
+            static fn (PublicKeyCredentialDescriptor $object): array => $object->jsonSerialize(),
+            $this->publicKeyCredentialDescriptors
+        );
     }
 
     public static function createFromString(string $data): self
     {
-        $data = json_decode($data, true);
+        $data = json_decode($data, true, 512, JSON_THROW_ON_ERROR);
         Assertion::isArray($data, 'Invalid data');
 
         return self::createFromArray($data);
