@@ -19,7 +19,7 @@ use ZipArchive;
 /*
 
   This code is part of LDAP Account Manager (http://www.ldap-account-manager.org/)
-  Copyright (C) 2020 - 2023  Roland Gruber
+  Copyright (C) 2020 - 2024  Roland Gruber
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -48,6 +48,8 @@ use ZipArchive;
 
 /** Access to persistence functions */
 include_once('../../lib/persistence.inc');
+/** account modules */
+include_once('../../lib/modules.inc');
 
 // start session
 if (isFileBasedSession()) {
@@ -76,7 +78,11 @@ if (isset($_POST['exportConfig']) && $cfg->checkPassword($_SESSION["mainconf_pas
 		if ($zipTmpFile === false) {
 		    throw new LAMException(_('Unable to create temporary file.'));
         }
-		$zipFile = stream_get_meta_data($zipTmpFile)['uri'];
+        $metaData = stream_get_meta_data($zipTmpFile);
+        if (empty($metaData['uri'])) {
+            throw new LAMException(_('Unable to create temporary file.'));
+        }
+		$zipFile = $metaData['uri'];
 		fclose($zipTmpFile);
 		$zip->open($zipFile, ZipArchive::CREATE);
 		$json = $exporter->exportAsJson();
@@ -87,7 +93,7 @@ if (isset($_POST['exportConfig']) && $cfg->checkPassword($_SESSION["mainconf_pas
 			throw new LAMException(_('Unable to create temporary file.'));
         }
         $fileSize = filesize($zipFile);
-		if ($fileSize === false) {
+		if (($fileSize === false) || ($fileSize <= 0)) {
 			throw new LAMException(_('Unable to create temporary file.'));
 		}
         $contents = fread($handle, $fileSize);
