@@ -170,7 +170,7 @@ if (isset($_POST['submitFormData'])) {
 	// set license
 	if (isLAMProVersion()) {
 		$licenseLines = explode("\n", $_POST['license']);
-		$licenseLines = array_map('trim', $licenseLines);
+		$licenseLines = array_map(trim(...), $licenseLines);
 		$cfg->setLicenseLines($licenseLines);
 		$cfg->licenseWarningType = $_POST['licenseWarningType'];
 		$cfg->licenseEmailFrom = $_POST['licenseEmailFrom'];
@@ -256,16 +256,7 @@ if (isset($_POST['submitFormData'])) {
 			$errors[] = _("Please enter a valid remote server in format \"server:port\".");
 		}
 	} else {
-	    $isValidLogFile = true;
-		if (!isset($_POST['logFile'])
-            || empty($_POST['logFile'])
-            || !preg_match("/^[a-z0-9\\/._-]+$/i", $_POST['logFile'])
-            || !(str_ends_with($_POST['logFile'], '.log') || str_ends_with($_POST['logFile'], '.txt'))
-            || str_contains($_POST['logFile'], '..')
-            || str_starts_with($_POST['logFile'], './')
-        ) {
-		    $isValidLogFile = false;
-		}
+	    $isValidLogFile = isset($_POST['logFile']) && LAMCfgMain::isValidLogFilename($_POST['logFile']);
 		$blockedPrefixes = ['/usr', '/etc', '/dev', '/boot', '/lib', '/proc', '/root', '/run', '/sys', '/snap'];
 		if (!empty($_SERVER['DOCUMENT_ROOT'])) {
             $blockedPrefixes[] = $_SERVER['DOCUMENT_ROOT'];
@@ -388,10 +379,17 @@ if (isset($_POST['submitFormData'])) {
 		}
 	}
 	$cfg->errorReporting = $_POST['errorReporting'];
+    // module settings
+    $allModules = getAllModules();
+    $moduleSettings = $cfg->getModuleSettings();
+    foreach ($allModules as $module) {
+        $module->checkGlobalConfigOptions($moduleSettings, $messages, $errors);
+    }
+    $cfg->setModuleSettings($moduleSettings);
 	// save settings
 	if (isset($_POST['submit'])) {
 		$cfg->save();
-		if (sizeof($errors) == 0) {
+		if (empty($errors)) {
 			$scriptTag = new htmlJavaScript('window.lam.dialog.showSuccessMessageAndRedirect("' . _("Your settings were successfully saved.") . '", "", "' . _('Ok') . '", "../login.php")');
 			parseHtml(null, $scriptTag, [], false, null);
 			echo '</body></html>';
@@ -405,14 +403,14 @@ if (isset($_POST['submitFormData'])) {
 
 	<?php
 	$row = new htmlResponsiveRow();
-	$row->add(new htmlTitle(_('General settings')), 12);
+	$row->add(new htmlTitle(_('General settings')));
 
 	// print messages
 	foreach ($errors as $error) {
-		$row->add(new htmlStatusMessage("ERROR", $error), 12);
+		$row->add(new htmlStatusMessage("ERROR", $error));
 	}
 	foreach ($messages as $message) {
-		$row->add(new htmlStatusMessage("INFO", $message), 12);
+		$row->add(new htmlStatusMessage("INFO", $message));
 	}
 
 	// check if config file is writable
@@ -706,6 +704,34 @@ if (isset($_POST['submitFormData'])) {
         }
 	}
 
+    // module settings
+	$modules = getAllModules();
+    $supportsGlobalCronJob = false;
+    foreach ($modules as $module) {
+        $supportsGlobalCronJob = $supportsGlobalCronJob || $module->supportsGlobalCronJob();
+        $moduleOptions = $module->getGlobalConfigOptions($cfg->getModuleSettings());
+        if (empty($moduleOptions)) {
+            continue;
+        }
+        $row->add(new htmlSubTitle($module->get_alias()));
+        foreach ($moduleOptions as $moduleOption) {
+            $row->add($moduleOption);
+        }
+		$row->addVerticalSpacer('3rem');
+    }
+
+    // global cron job
+    if ($supportsGlobalCronJob) {
+		$row->add(new htmlSubTitle(_('Global cron job')));
+        $cronCommand = dirname(__FILE__, 3) . '/lib/runCronJobs.sh all';
+        $row->addLabel(new htmlOutputText('Cron command'));
+		$cmdGroup = new htmlGroup();
+		$cmdGroup->addElement(new htmlOutputText('0 0 * * * ' . $cronCommand));
+		$cmdGroup->addElement(new htmlSpacer('2rem', null));
+		$cmdGroup->addElement(new htmlHelpLink('294'));
+		$row->addField($cmdGroup);
+    }
+
 	// change master password
 	$row->add(new htmlSubTitle(_("Change master password")));
 	$pwd1 = new htmlResponsiveInputField(_("New master password"), 'masterpassword', '', '235');
