@@ -10,7 +10,7 @@ use \htmlSubTitle;
 /*
 
   This code is part of LDAP Account Manager (http://www.ldap-account-manager.org/)
-  Copyright (C) 2009 - 2023  Roland Gruber
+  Copyright (C) 2009 - 2024  Roland Gruber
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -113,7 +113,7 @@ printConfigurationPageHeaderBar($conf);
 
 // print error messages
 for ($i = 0; $i < sizeof($errorsToDisplay); $i++) {
-	call_user_func_array('StatusMessage', $errorsToDisplay[$i]);
+	call_user_func_array(StatusMessage(...), $errorsToDisplay[$i]);
 }
 
 echo "<form id=\"inputForm\" action=\"moduleSettings.php\" method=\"post\" autocomplete=\"off\" onSubmit=\"window.lam.utility.saveScrollPosition('inputForm')\" novalidate=\"novalidate\">\n";
