@@ -204,7 +204,7 @@ include __DIR__ . '/../../lib/adminHeader.inc';
 // print error messages if any
 if (sizeof($saveErrors) > 0) {
 	foreach ($saveErrors as $saveError) {
-		call_user_func_array('StatusMessage', $saveError);
+		call_user_func_array(StatusMessage(...), $saveError);
 	}
 	echo "<br>\n";
 }
@@ -263,7 +263,10 @@ $foldingMarks = 'no';
 if (isset($_SESSION['currentPDFStructure'])) {
 	$foldingMarks = $_SESSION['currentPDFStructure']->getFoldingMarks();
 }
-$possibleFoldingMarks = [_('No') => 'no', _('Yes') => 'standard'];
+$possibleFoldingMarks = [
+    _('No') => PDFStructure::FOLDING_NONE,
+    _('Yes') => PDFStructure::FOLDING_STANDARD
+];
 $foldingMarksSelect = new htmlResponsiveSelect('foldingmarks', $possibleFoldingMarks, [$foldingMarks], _('Folding marks'));
 $foldingMarksSelect->setHasDescriptiveElements(true);
 $mainContent->add($foldingMarksSelect, 12);
