@@ -3,7 +3,7 @@ namespace LAM\UPLOAD;
 /*
 
   This code is part of LDAP Account Manager (http://www.ldap-account-manager.org/)
-  Copyright (C) 2004 - 2023  Roland Gruber
+  Copyright (C) 2004 - 2024  Roland Gruber
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -21,6 +21,10 @@ namespace LAM\UPLOAD;
 
 */
 
+use htmlDiv;
+use htmlJavaScript;
+use htmlResponsiveRow;
+
 /**
 * Creates LDAP accounts for file upload.
 *
@@ -76,15 +80,10 @@ if (!checkIfNewEntriesAreAllowed($type->getId()) || !checkIfWriteAccessIsAllowed
 	die();
 }
 
-echo '<div id="uploadContent" class="smallPaddingContent">';
-$tokenPrefix = '?' . getSecurityTokenName() . '=' . getSecurityTokenValue();
-?>
-	<script type="text/javascript">
-		jQuery(document).ready(function(){
-			window.lam.upload.continueUpload('../misc/ajax.php?function=upload&typeId=' + '<?php echo $type->getId() ?>', '<?php echo getSecurityTokenName(); ?>', '<?php echo getSecurityTokenValue(); ?>');
-		});
-	</script>
+$container = new htmlResponsiveRow();
+$javaScript = new htmlJavaScript('window.lam.upload.continueUpload(\'../misc/ajax.php?function=upload&typeId=' . $type->getId() . '\', \'' . getSecurityTokenName() . '\', \'' . getSecurityTokenValue() . '\');');
+$contentDiv = new htmlDiv('uploadContent', $javaScript, ['smallPaddingContent']);
+$container->add($contentDiv);
+parseHtml(null, $container, [], false, null);
 
-<?php
-echo '</div>';
 include __DIR__ . '/../../lib/adminFooter.inc';
